==> connector-service-1.0.0-20191017.033313-64-sources.jar: com/bizvane/connectorservice/entity/icrm/AddVipResponseVO.java <==
package com.bizvane.connectorservice.entity.icrm;

import java.io.Serializable;

public class AddVipResponseVO implements Serializable {

    private String vip_code;
    private String customer_name;
    private String tel;
    private String org_code;
    private String shop_code;
    private String  customer_sex;//性别 1：男 2：女 0: 保密
    private String birthday;
    private String series_code;//系列代码
    private String level_code;//等级代码
    private String source;//来源
    private String customer_type;//顾客类型
    private String recommend_tel;//推荐人手机号
    private String country;//国家
    private String province;//省市
    private String city;//城市
    private String district;//区域
    private String address;//地址
    private String email;//邮箱
    private String is_add_time;//新增时间
    private String remark;//备注
    private String customer_tel;//顾客手机
    private String is_add_person;//添加人
    private String is_fetch;//0：正常 1：待处理
    private String brand_code;//品牌
    private String status;//状态VIP卡状态 0：未激活 1：激活 2：停用 3：挂失
    private String customer_code;//顾客代码
    private String password;//密码
    private String customer_level;//顾客等级
    private String vip_id;//
    private String vip_code_unique;//vip唯一值

    public String getVip_code() {
        return vip_code;
    }

    public void setVip_code(String vip_code) {
        this.vip_code = vip_code;
    }

    public String getCustomer_name() {
        return customer_name;
    }

    public void setCustomer_name(String customer_name) {
        this.customer_name = customer_name;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public String getOrg_code() {
        return org_code;
    }

    public void setOrg_code(String org_code) {
        this.org_code = org_code;
    }

    public String getShop_code() {
        return shop_code;
    }

    public void setShop_code(String shop_code) {
        this.shop_code = shop_code;
    }

    public String getCustomer_sex() {
        return customer_sex;
    }

    public void setCustomer_sex(String customer_sex) {
        this.customer_sex = customer_sex;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getSeries_code() {
        return series_code;
    }

    public void setSeries_code(String series_code) {
        this.series_code = series_code;
    }

    public String getLevel_code() {
        return level_code;
    }

    public void setLevel_code(String level_code) {
        this.level_code = level_code;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getCustomer_type() {
        return customer_type;
    }

    public void setCustomer_type(String customer_type) {
        this.customer_type = customer_type;
    }

    public String getRecommend_tel() {
        return recommend_tel;
    }

    public void setRecommend_tel(String recommend_tel) {
        this.recommend_tel = recommend_tel;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getIs_add_time() {
        return is_add_time;
    }

    public void setIs_add_time(String is_add_time) {
        this.is_add_time = is_add_time;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getCustomer_tel() {
        return customer_tel;
    }

    public void setCustomer_tel(String customer_tel) {
        this.customer_tel = customer_tel;
    }

    public String getIs_add_person() {
        return is_add_person;
    }

    public void setIs_add_person(String is_add_person) {
        this.is_add_person = is_add_person;
    }

    public String getIs_fetch() {
        return is_fetch;
    }

    public void setIs_fetch(String is_fetch) {
        this.is_fetch = is_fetch;
    }

    public String getBrand_code() {
        return brand_code;
    }

    public void setBrand_code(String brand_code) {
        this.brand_code = brand_code;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getCustomer_code() {
        return customer_code;
    }

    public void setCustomer_code(String customer_code) {
        this.customer_code = customer_code;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getCustomer_level() {
        return customer_level;
    }

    public void setCustomer_level(String customer_level) {
        this.customer_level = customer_level;
    }

    public String getVip_id() {
        return vip_id;
    }

    public void setVip_id(String vip_id) {
        this.vip_id = vip_id;
    }

    public String getVip_code_unique() {
        return vip_code_unique;
    }

    public void setVip_code_unique(String vip_code_unique) {
        this.vip_code_unique = vip_code_unique;
    }
}

==> connector-service-1.0.0-20191205.110947-96-sources.jar: com/bizvane/connectorservice/entity/icrm/AddVipResponseVO.java <==
package com.bizvane.connectorservice.entity.icrm;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

public class AddVipResponseVO implements Serializable {
    @ApiModelProperty(
            value = "会员卡号",
            name = "vip_code",
            required = false,
            example = ""
    )
    private String vip_code;

    @ApiModelProperty(
            value = "姓名",
            name = "customer_name",
            required = false,
            example = ""
    )
    private String customer_name;

    @ApiModelProperty(
            value = "手机号",
            name = "tel",
            required = false,
            example = ""
    )
    private String tel;
    private String org_code;
    @ApiModelProperty(
            value = "店铺代码",
            name = "shop_code",
            required = false,
            example = ""
    )
    private String shop_code;
    @ApiModelProperty(
            value = "性别 1：男 2：女 0: 保密",
            name = "customer_sex",
            required = false,
            example = ""
    )
    private String  customer_sex;//性别 1：男 2：女 0: 保密

    @ApiModelProperty(
            value = "生日",
            name = "birthday",
            required = false,
            example = ""
    )
    private String birthday;
    private String series_code;//系列代码

    @ApiModelProperty(
            value = "等级代码",
            name = "level_code",
            required = false,
            example = ""
    )
    private String level_code;//等级代码
    private String source;//来源
    @ApiModelProperty(
            value = "顾客类型",
            name = "customer_type",
            required = false,
            example = ""
    )
    private String customer_type;//顾客类型
    private String recommend_tel;//推荐人手机号
    private String country;//国家
    private String province;//省市
    private String city;//城市
    private String district;//区域
    private String address;//地址
    private String email;//邮箱
    private String is_add_time;//新增时间
    private String remark;//备注

    @ApiModelProperty(
            value = "顾客手机",
            name = "customer_tel",
            required = false,
            example = ""
    )
    private String customer_tel;//顾客手机
    private String is_add_person;//添加人
    private String is_fetch;//0：正常 1：待处理
    private String brand_code;//品牌

    @ApiModelProperty(
            value = "状态VIP卡状态 0：未激活 1：激活 2：停用 3：挂失",
            name = "status",
            required = false,
            example = ""
    )
    private String status;//状态VIP卡状态 0：未激活 1：激活 2：停用 3：挂失

    @ApiModelProperty(
            value = "顾客代码",
            name = "customer_code",
            required = false,
            example = ""
    )
    private String customer_code;//顾客代码
    @ApiModelProperty(
            value = "密码",
            name = "password",
            required = false,
            example = ""
    )
    private String password;//密码

    @ApiModelProperty(
            value = "顾客等级",
            name = "customer_level",
            required = false,
            example = ""
    )
    private String customer_level;//顾客等级
    @ApiModelProperty(
            value = "erpid",
            name = "vip_id",
            required = false,
            example = ""
    )
    private String vip_id;//
    private String vip_code_unique;//vip唯一值


    @ApiModelProperty(
            value = "绑卡或开卡，0:绑卡,1:开卡",
            name = "bindOrOpencardType",
            required = false,
            example = ""
    )
    private String bindOrOpencardType;
    public String getVip_code() {
        return vip_code;
    }

    public void setVip_code(String vip_code) {
        this.vip_code = vip_code;
    }

    public String getCustomer_name() {
        return customer_name;
    }

    public void setCustomer_name(String customer_name) {
        this.customer_name = customer_name;
    }

    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }

    public String getOrg_code() {
        return org_code;
    }

    public void setOrg_code(String org_code) {
        this.org_code = org_code;
    }

    public String getShop_code() {
        return shop_code;
    }

    public void setShop_code(String shop_code) {
        this.shop_code = shop_code;
    }

    public String getCustomer_sex() {
        return customer_sex;
    }

    public void setCustomer_sex(String customer_sex) {
        this.customer_sex = customer_sex;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getSeries_code() {
        return series_code;
    }

    public void setSeries_code(String series_code) {
        this.series_code = series_code;
    }

    public String getLevel_code() {
        return level_code;
    }

    public void setLevel_code(String level_code) {
        this.level_code = level_code;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getCustomer_type() {
        return customer_type;
    }

    public void setCustomer_type(String customer_type) {
        this.customer_type = customer_type;
    }

    public String getRecommend_tel() {
        return recommend_tel;
    }

    public void setRecommend_tel(String recommend_tel) {
        this.recommend_tel = recommend_tel;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getIs_add_time() {
        return is_add_time;
    }

    public void setIs_add_time(String is_add_time) {
        this.is_add_time = is_add_time;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getCustomer_tel() {
        return customer_tel;
    }

    public void setCustomer_tel(String customer_tel) {
        this.customer_tel = customer_tel;
    }

    public String getIs_add_person() {
        return is_add_person;
    }

    public void setIs_add_person(String is_add_person) {
        this.is_add_person = is_add_person;
    }

    public String getIs_fetch() {
        return is_fetch;
    }

    public void setIs_fetch(String is_fetch) {
        this.is_fetch = is_fetch;
    }

    public String getBrand_code() {
        return brand_code;
    }

    public void setBrand_code(String brand_code) {
        this.brand_code = brand_code;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getCustomer_code() {
        return customer_code;
    }

    public void setCustomer_code(String customer_code) {
        this.customer_code = customer_code;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getCustomer_level() {
        return customer_level;
    }

    public void setCustomer_level(String customer_level) {
        this.customer_level = customer_level;
    }

    public String getVip_id() {
        return vip_id;
    }

    public void setVip_id(String vip_id) {
        this.vip_id = vip_id;
    }

    public String getVip_code_unique() {
        return vip_code_unique;
    }

    public void setVip_code_unique(String vip_code_unique) {
        this.vip_code_unique = vip_code_unique;
    }

    public String getBindOrOpencardType() {
        return bindOrOpencardType;
    }

    public void setBindOrOpencardType(String bindOrOpencardType) {
        this.bindOrOpencardType = bindOrOpencardType;
    }
}
